@@ -3,6 +3,15 @@ import execjs
 import json
 import requests as rq
 import pandas as pd
+import time
+import logging
+
+logging.basicConfig(
+    level=logging.INFO,
+    format='[pywencai] %(asctime)s - %(levelname)s - %(message)s'
+)
+
+# logging.getLogger().addHandler(logging.StreamHandler())
 
 # 获取token
 def getToken():
@@ -50,6 +59,9 @@ def getIds(query_type):
 # 获取每页数据
 def getPage(**kwargs):
   kwargs = {replace_key(key): value for key, value in kwargs.items()}
+  retry = kwargs.pop('retry', 10)
+  sleep = kwargs.pop('sleep', 1)
+
   data = {
     'perpage': 100,
     'page': 1,
@@ -57,18 +69,32 @@ def getPage(**kwargs):
     **getIds(kwargs.get('query_type', 'stock')),
     **kwargs
   }
-  res = rq.request(
-    method='POST',
-    url='http://www.iwencai.com/gateway/urp/v7/landing/getDataList',
-    data=data,
-    headers={
-      'hexin-v': getToken(),
-      'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/102.0.0.0 Safari/537.36'
-    }
-  )
-  result = json.loads(res.text)
-  list = result['answer']['components'][0]['data']['datas']
-  return pd.DataFrame.from_dict(list)
+  count = 0
+  logging.info(f'第{data.get("page")}页开始')
+
+  while count < retry :
+    time.sleep(sleep)
+    try: 
+      res = rq.request(
+        method='POST',
+        url='http://www.iwencai.com/gateway/urp/v7/landing/getDataList',
+        data=data,
+        headers={
+          'hexin-v': getToken(),
+          'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/102.0.0.0 Safari/537.36'
+        },
+        timeout=(5, 10)
+      )
+      result = json.loads(res.text)
+      list = result['answer']['components'][0]['data']['datas']
+      logging.info(f'第{data.get("page")}页成功')
+      return pd.DataFrame.from_dict(list)
+    except:
+      logging.warning(f'{count+1}次尝试失败')
+      count+=1
+  logging.error(f'第{data.get("page")}页失败')
+  return pd.DataFrame.from_dict([])
+  
 
 # 是否继续循环
 def canLoop(loop, count):
